@@ -2,6 +2,7 @@ import os
 import sys
 import time
 import glob
+import json
 import datetime
 from pathlib import Path
 import re
@@ -19,7 +20,6 @@ logger = logging.getLogger(__name__)
 CLEANUP_INTERVAL_MS = 0.999
 
 
-
 class BatchProcessor:
     def __init__(self, config):
         self.config = config
@@ -219,9 +219,9 @@ class BatchProcessor:
         result = None
         try:
             # We cap runtime at TTL if set or DEFAULT_TTL as default
-            timeout = item.get('ttl_seconds')
-            if not timeout or timeout <=0:
-                timeout = self.config.get('batch-default-ttl', 30)
+            timeout = item.get("ttl_seconds")
+            if not timeout or timeout <= 0:
+                timeout = self.config.get("batch-default-ttl", 30)
             watchdog = fk.utils.Watchdog.Watchdog(timeout, self._watchdog_hang_detected)
             # logger.info("££££ Entry")
             unpackable = entrypoint(item, self.config)
@@ -328,10 +328,22 @@ class BatchProcessor:
         # logger.info(f"No pending items found")
         return False
 
+    # Make sure data is a string ready for insertion into db
+    def _prepare_data(self, data):
+        if data == None:
+            return None
+        data_type = type(data)
+        if data_type is dict:
+            data = json.dumps(data, indent=3, sort_keys=True, default=str)
+        elif data_type is not str:
+            data = str(data)
+        return data
+
     def insert_batch_item(self, type="test", data=None, ttl_seconds=None, result=None, priority=50, source=None, throttle_key=None, throttle_limit=1, throttle_period=1):
         """
         Insert a new batch item into the database, ready for execution
         """
+        data = self._prepare_data(data)
         # fmt: off
         return self.db.insert_batch_item(
             {
@@ -370,6 +382,9 @@ class BatchProcessor:
     def retry_job_by_id(self, id):
         self.db.bump_batch_item_status(id, self.db.PENDING)
 
+    def delete_job_by_id(self, id):
+        self.db.delete_by_id(id)
+
     def get_job_counts(self):
         raw = self.db.get_job_counts()
         out = {}
@@ -388,10 +403,10 @@ class BatchProcessor:
         # fmt: off
         status = {
             "status": self.db.get_status_counts(),
-            "last": self.db.get_last_jobs(limit=20),
-            "last_failed": self.db.get_last_jobs(limit=20, status=["failed"]),
-            "last_pending": self.db.get_last_jobs(limit=20, status=["pending"]),
-            "last_in_progress": self.db.get_last_jobs(limit=20, status=["in-progress"]),
+#            "last": self.db.get_last_jobs(limit=20),
+#            "last_failed": self.db.get_last_jobs(limit=20, status=["failed"]),
+#            "last_pending": self.db.get_last_jobs(limit=20, status=["pending"]),
+#            "last_in_progress": self.db.get_last_jobs(limit=20, status=["in-progress"]),
             "counts": self.get_job_counts()}
         # fmt: on
         return status
